@@ -1,7 +1,7 @@
 #ifndef WINPR_BUILD_FLAGS_H
 #define WINPR_BUILD_FLAGS_H
 
-#define WINPR_CFLAGS "-march=x86-64  -mtune=generic -O2 -pipe -fvisibility=hidden -fno-omit-frame-pointer -Wredundant-decls -fsigned-char -Wimplicit-function-declaration -fvisibility=hidden -O3 -DNDEBUG"
+#define WINPR_CFLAGS "-march=x86-64  -mtune=generic -O2 -pipe -fvisibility=hidden -fno-omit-frame-pointer -Wredundant-decls -fsigned-char -Wimplicit-function-declaration -Wno-jump-misses-init -fvisibility=hidden -O3 -DNDEBUG"
 #define WINPR_COMPILER_ID "GNU"
 #define WINPR_COMPILER_VERSION "15.2.1"
 #define WINPR_TARGET_ARCH "x64"
